import QtQuick 1.1
import qb.components 1.0

/// Main screen of the Thermostat application showing thermostat modes and set values.

Screen {
	id: thermostatScreen

	screenTitleIconUrl: "./drawables/Temperature.svg"
	screenTitle: qsTr("Temperature presets")

	onHidden: {
		app.updateTemperaturePreset({'thermStateRelax': modeComfort.temperature,
									 'thermStateActive': modeHome.temperature,
									 'thermStateSleep': modeSleep.temperature,
									 'thermStateAway': modeAway.temperature
									});
	}

	onShown: {
		modeComfort.temperature = app.thermStates.thermStateRelax.temperature;
		modeHome.temperature = app.thermStates.thermStateActive.temperature;
		modeSleep.temperature = app.thermStates.thermStateSleep.temperature;
		modeAway.temperature = app.thermStates.thermStateAway.temperature;
	}

	Item {
		id: modesWrap

		anchors.top: parent.top
		anchors.topMargin: 84
		width: 717
		anchors.horizontalCenter: parent.horizontalCenter

		TemperatureModeSet {
			id: modeAway

			label: app.thermStateName[app.thermStateAway]
			color: app.thermStateColor[app.thermStateAway]
			temperature: app.thermStates.thermStateAway.temperature
		}

		TemperatureModeSet {
			id: modeSleep

			label: app.thermStateName[app.thermStateSleep]
			color: app.thermStateColor[app.thermStateSleep]
			anchors {
				left: modeAway.right
				leftMargin: 19
			}
			temperature: app.thermStates.thermStateSleep.temperature
		}

		TemperatureModeSet {
			id: modeHome

			label: app.thermStateName[app.thermStateActive]
			color: app.thermStateColor[app.thermStateActive]

			anchors {
				left: modeSleep.right
				leftMargin: 19
			}
			temperature: app.thermStates.thermStateActive.temperature
		}

		TemperatureModeSet {
			id: modeComfort

			label: app.thermStateName[app.thermStateRelax]
			color: app.thermStateColor[app.thermStateRelax]

			anchors {
				left: modeHome.right
				leftMargin: 19
			}
			temperature: app.thermStates.thermStateRelax.temperature
		}
	}

	Text {
		id: infoText

		anchors {
			baseline: parent.bottom
			baselineOffset: -115
			horizontalCenter: parent.horizontalCenter
		}
		font {
			family:qfont.regular.name
			pixelSize: qfont.bodyText
		}
		color: "#565656"

		// TODO: Translated by google translator
		text: qsTr("You can set four temperature settings.<br>If you change the temperature, it also changes in the weekly program.")
	}
}
