import QtQuick 1.1
import qb.components 1.0
import "../../themes"

/// Screen for setting vacation details.

Screen {
	id: vacationSetScreen
	screenTitle: qsTr("Vacation set")
	isSaveCancelDialog: true

	onSaved: {
		modeVacation.temperatureChanged();
		app.updateVacationData(app.tmpVacationData);
	}

	onShown: {
		if (args && args.newVacation) {
			var newVacationData = app.vacationData;
			var now = new Date();
			now.setMinutes(0, 0, 0);

			var vacationData = app.vacationData;
			newVacationData.startTime = now.getTime();
			btnStartDate.text = app.formatDateTime(now.getTime(), true);

			var future = new Date(now);
			future.setFullYear(future.getFullYear() + 5);
			newVacationData.endTime = future.getTime();
			btnEndDate.text = app.formatDateTime(future.getTime(), false);

			modeVacation.temperature = 6.0; // default vacation temperature
			app.tmpVacationData = newVacationData;
		} else {
			if (args && args.editVacation)
				app.tmpVacationData = app.vacationData;

			modeVacation.temperature = app.tmpVacationData.temperature;
			btnStartDate.text = app.formatDateTime(app.tmpVacationData['startTime'], true);
			btnEndDate.text = app.formatDateTime(app.tmpVacationData['endTime'], false);
		}
	}

	Row {

		id: page
		property int textColorGap: 6

		anchors {
			horizontalCenter: parent.horizontalCenter
			//verticalCenter: parent.verticalCenter
			top: parent.top
			topMargin: Math.round(parent.height / 6.0)

		}

		spacing: 10

		TemperatureModeSet {
			id: modeVacation
			anchors.top: parent.top
			label: qsTr("Temperature")
			color: "#FF9900"
			textColorGap: page.textColorGap
			temperature: 6
			onTemperatureChanged: {
				var vacData = app.tmpVacationData;
				vacData.temperature = temperature;
				app.tmpVacationData = vacData;
			}
		}

		Item {
			id: spacer
			width: 64
			height: 1
		}

		Column {

			id: startDate
			spacing: 5
			anchors.top: parent.top

			Text {
				id: txtStartDate
				text: qsTr("Start date")
				font {
					family: qfont.semiBold.name
					pixelSize: qfont.navigationTitle
				}
				color: "#565656"
			}

			Rectangle {
				height: page.textColorGap
				width: parent.width
				color: colors.canvas
			}

			RichTextButton {
				id: btnStartDate
				text: qsTr("Now")
				width: 165
				height: 109
				kpiPostfix: "startDate"
				colorUp: colors.tempTileBackgroundUp
				fontColorUp: colors.tempTileTextUp
				fontFamily: "Open Sans Regular"
				fontPixelSize: qfont.titleText
				onClicked: {
					// set the minimum start time to now at most recent full hour
					var minDt = new Date();
					minDt.setMinutes(0, 0, 0);

					// set the initial value to the starting time of the vacation
					var init = new Date(app.tmpVacationData['startTime']);

					// set the maximum start time to the minimum plus two years
					var maxDt = new Date(minDt);
					maxDt.setFullYear(maxDt.getFullYear() + 2);

					// if vacation already has an end and it is before the start maximum,
					// set the start maximum to the end minus 1 hour
					if (app.tmpVacationData['endTime'] < maxDt.getTime()) {
						maxDt.setTime(app.tmpVacationData['endTime']);
						maxDt.setHours(maxDt.getHours() - 1);
					}

					stage.openFullscreen(app.vacationDateScreenUrl, {dateToChange: "startTime", initDt: init, minDt: minDt, maxDt: maxDt});
				}

			}

		}

		Column {

			spacing: 5
			anchors.top: parent.top

			Text {
				text: " "
				font {
					family: qfont.semiBold.name
					pixelSize: qfont.navigationTitle
				}

			}

			Rectangle {
				height: page.textColorGap
				width: parent.width
				color: colors.canvas
			}

			Rectangle {
				height: 109
				width: txtTo.width
				color: colors.canvas

				Text {
					id: txtTo
					text: qsTr("to")

					anchors.verticalCenter: parent.verticalCenter

					horizontalAlignment: Text.AlignHCenter
					verticalAlignment: Text.AlignVCenter

					font {
						family: qfont.regular.name
						pixelSize: qfont.titleText
					}

					color: "#565656"
				}
			}
		}

		Column {

			id: endDate
			spacing: 5
			anchors.top: parent.top

			Text {
				id: txtEndDate
				text: qsTr("End date")
				font {
					family: qfont.semiBold.name
					pixelSize: qfont.navigationTitle
				}
				color: "#565656"
			}

			Rectangle {
				height: page.textColorGap
				width: parent.width
				color: colors.canvas
			}

			RichTextButton {
				id: btnEndDate
				width: 165
				height: 109
				colorUp: colors.tempTileBackgroundUp
				fontColorUp: colors.tempTileTextUp
				text: qsTr("Until I return")
				kpiPostfix: "endDate"
				fontFamily: "Open Sans Regular"
				fontPixelSize: qfont.titleText
				onClicked: {
					var now = new Date();
					// initialy set the end time to the start time's next full hour
					var init = new Date(app.tmpVacationData['startTime']);
					init.setHours(init.getHours() + 1);

					// if initial end time is in the past (because we are editing)
					// a previously created vacation, set initial end time to next full hour
					if (init.getTime() < now.getTime()) {
						init = now;
						init.setMinutes(0, 0, 0);
						init.setHours(init.getHours() + 1);
					}

					// minimum end time is also the initial date and time
					var minDt = new Date(init);
					// maximum end time is minimum plus two years
					var maxDt = new Date(minDt);
					maxDt.setFullYear(maxDt.getFullYear() + 2);

					// if vacation already has an end time and its smaller than
					// calculated maximum end time, set the initial end time to that
					if (app.tmpVacationData['endTime'] < maxDt.getTime()) {
						init.setTime(app.tmpVacationData['endTime']);
					}

					stage.openFullscreen(app.vacationDateScreenUrl, {dateToChange: "endTime", initDt: init, minDt: minDt, maxDt: maxDt});
				}
			}

		}

	}
}
